******************************************
******************************************
**                                      **
**  KENYA DHS ANALYSIS FOR MVP PROJECT  **
**                                      **
******************************************
******************************************

**All files with "KE" prefix pertain to files directly downloaded from DHS surveys of Kenya in 2003 and 2008.
**These files can be downloaded here: http://www.measuredhs.com/accesssurveys/search/show_datasets.cfm?Surv_Id=300&Ctry_id=20&SrvyTp=available&flag=0
** and here: http://www.measuredhs.com/accesssurveys/search/show_datasets.cfm?Surv_Id=216&Ctry_id=20&SrvyTp=available&flag=0
** There are no modifications required to the DHS data to run this do-file. 

version 11
clear all
set matsize 800
set more off


********************
********************
**                **
**   KENYA 2008   **
**                **
********************
********************

cd "H:\CGD work\Migration\Millenium Villages\For website"
use "KEPR51FL.DTA", clear

* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 5 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture set, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Creating a subset of one observation per household.
sort hhid
by hhid: gen hhmem = 1 if _n == 1
replace hhmem = 0 if hhmem ==.


***************
*  Schooling  *
***************

*** Checking for comparison to Final Report
gen attended_primary = hv122==1 if (hv105>5 & hv103==1)
gen age = hv105
gen primaryage = (age >= 6 & age <= 13) if hv103==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): total attended_primary 
	matrix aux_prim_students_`x'08 = e(b)
	sca prim_students_`x'08=aux_prim_students_`x'08[1,1] 
svy, subpop (if `x'): total primaryage
	matrix aux_prim_age_kids_`x'08 = e(b)
	sca prim_age_kids_`x'08=aux_prim_age_kids_`x'08[1,1]
sca prim_result_gen_`x'08 = prim_students_`x'08/prim_age_kids_`x'08	
dis prim_result_gen_`x'08
svy, subpop (if `x'): ratio attended_primary / primaryage
}
* Agrees with Kenya DHS 2008 Final Report Table 2.4 page 18

*** Recalculating with numerator including children below 6 for comparability with MVP report
drop attended_primary
gen attended_primary = hv122==1 if hv103==1

/* Use bootstrap command to produce standard errors. Bootstrap does not allow pweights => transform the
variables first. Check against the clasissical way of calculating the GPA ratio */

gen prage=weight*primaryage if attended_primary!=.
gen attprimary=weight*attended_primary

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): ratio attended_primary / primaryage
*bootstrap, rep(1000) strata(hv022) cluster(hv001): ratio attprimary / prage if `x'
	matrix aux_gpa_`x'08=e(b)
	sca prim_result_`x'08=aux_gpa_`x'08[1,1]
	matrix aux2_gpa_`x'08=e(V)
	sca var=aux2_gpa_`x'08[1,1]
	sca prim_sd_`x'08=sqrt(var)
dis prim_result_`x'08
dis prim_sd_`x'08
}

*************
*  Bednets  *
*************

gen age_new=hml16
gen itn=hml12==1

foreach x of varlist all rural mvregion {
svy, subpop (if (age_new<5 & hv103==1 & `x')) : proportion itn
	matrix aux_itn_`x'08=e(b)
	sca itn_result_`x'08=aux_itn_`x'08[1,2]
	matrix aux2_itn_`x'08=e(V)
	sca var=aux2_itn_`x'08[2,2]
	sca itn_sd_`x'08=sqrt(var)
sca itn_result_`x'08=itn_result_`x'08
sca itn_sd_`x'08=itn_sd_`x'08
dis itn_result_`x'08
dis itn_sd_`x'08
}
* Agrees with Kenya DHS 2008 Final Report Table 12.2 page 165


*******************
*  Mobile phones  *
*******************

gen hasmobile = hv243a == 1
preserve
sort hhid
by hhid: egen mobile = max(hasmobile)
replace mobile = . if mobile == 9

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1): proportion mobile  
	matrix aux_phone_`x'08=e(b)
	sca phone_result_`x'08=aux_phone_`x'08[1,2]
	matrix aux2_phone_`x'08=e(V)
	sca var=aux2_phone_`x'08[2,2]
	sca phone_sd_`x'08=sqrt(var)
dis phone_result_`x'08
dis phone_sd_`x'08
}
restore
* Agrees with Final Report table 2.9 p. 25


***********
*  Water  *
***********

* First check against data in Kenya 2008 DHS Final Report
* Improved source of drinking water. 

gen improved_drinking = 0
replace improved_drinking = 1 if (hv201 >= 10 & hv201 <= 31) | hv201 == 41 | hv201 == 51
by hhid: egen hhimproved_drinking = max(improved_drinking)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1): proportion hhimproved_drinking 
	matrix aux_water_`x'08=e(b)
	sca water_result2_`x'08=aux_water_`x'08[1,2]
	matrix aux2_water_`x'08=e(V)
	sca var=aux2_water_`x'08[2,2]
	sca water_sd2_`x'08=sqrt(var)
dis water_result2_`x'08
dis water_sd2_`x'08
}

/* There is only 1 category for "spring" in 2003 whereas there are two categories in 2008:
protected spring (improved) and unprotected spring (not improved).
We need to save "relative" and "absolute" percentage of protected spring for further analysis in 2003 */

* 1. "Relative" proportion of protected springs out of all springs (protected and unprotected)

gen protspring=1 if hv201==41
replace protspring=0 if hv201==42
by hhid: egen hh_protspring = max(protspring)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hh_protspring 
	matrix aux_spring_`x'08=e(b)
	sca spring_relative_`x'08=aux_spring_`x'08[1,2]
dis spring_relative_`x'08
}

* 2. "Absolute" proportion of protected springs out of all types of water supply types.

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hv201 
	matrix aux_spring2_`x'08=e(b)
	sca spring_absolute_`x'08=aux_spring2_`x'08[1,7]
	matrix aux2_spring2_`x'08 = e(V)
	sca var = aux2_spring2_`x'08[7,7]
	sca spring_absolutesd_`x'08= sqrt(var)
dis spring_absolute_`x'08
dis spring_absolutesd_`x'08
}


****************
*  Sanitation  *
****************

* First check against data in Kenya 2008 DHS Final Report
* Note that Final Report p. 22 defines any shared facility as non-improved
gen improved_sanitation = 0
replace improved_sanitation = 1 if ((hv205 >= 11 & hv205<= 13) | hv205 == 21| hv205 == 22) & hv225 == 0
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

svy, subpop ( if hhmem == 1): proportion hhimproved_sanitation
svy, subpop ( if rural==1 & hhmem == 1): proportion hhimproved_sanitation

drop improved_sanitation
drop hhimproved_sanitation

/* BUT the MV report does *not* define 'shared' as 'unimproved'
Furthermore, ALL flush toilets shall be defined as improved
So the calculation must be redone for comparability: */
 
gen improved_sanitation = 0
replace improved_sanitation = 1 if (hv205 >= 11 & hv205<= 22)
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hhimproved_sanitation 
	matrix aux_sani_`x'08=e(b)
	sca sani_result2_`x'08=aux_sani_`x'08[1,2]
	matrix aux2_sani_`x'08=e(V)
	sca var=aux2_sani_`x'08[2,2]
	sca sani_sd2_`x'08=sqrt(var)
dis sani_result2_`x'08
dis sani_sd2_`x'08
}

/* There is only 1 category for "traditional pit latrine" in 2003 whereas there are two categories in 2008:
with slab (improved) and without slab (not improved).
We need to save "relative" and "absolute" percentage of latrine with slab for further analysis in 2003 */

* 1. "Relative" proportion of latrine with slab out of all latrines (with and without slab)

gen slabpit=1 if hv205==22
replace slabpit=0 if hv205==23
by hhid: egen hh_slabpit = max(slabpit)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hh_slabpit 
	matrix aux_pit_`x'08=e(b)
	sca slab_relative_`x'08=aux_pit_`x'08[1,2]
dis slab_relative_`x'08
}

* 2. "Absolute" proportion of latrines with slab out of all types of sanitation facilities.

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hv205 
	matrix aux_pit2_`x'08=e(b)
	sca slab_absolute_`x'08=aux_pit2_`x'08[1,7]
	matrix aux2_pit2sd_`x'08 = e(V)
	sca var = aux2_pit2sd_`x'08[7,7]
	sca slab_absolutesd_`x'08 = sqrt(var)
dis slab_absolute_`x'08
dis slab_absolutesd_`x'08 
}


*************************
*  Measles vaccination  *
*************************

preserve
use "KEKR51FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen age_years = b8
gen measles = (h9 == 1 | h9 == 2 | h9 == 3)
* Note: the survey asks mothers if children aged 12-23 months received vaccinations at any time before the survey:

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_years==1): proportion measles 
	matrix aux_measles_`x'08=e(b)
	sca measles_result_`x'08=aux_measles_`x'08[1,2]
	matrix aux2_measles_`x'08=e(V)
	sca var=aux2_measles_`x'08[2,2]
	sca measles_sd_`x'08=sqrt(var)
dis measles_result_`x'08
dis measles_sd_`x'08
}
restore
* Agrees with Final Report table 10.3 page 131


**********************
*  Birth attendance  *
**********************

preserve
use "KEKR51FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen skilled = .
replace skilled = 1 if m3a == 1 | m3b == 1
replace skilled = 0 if skilled != 1 & (m3a != . | m3b != . | m3c != . | m3d != .)

*** Checking for comparison to Final Report
foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion skilled 
	matrix aux_skilled_gen_`x'08=e(b)
	sca skilled_gen_result_`x'08=aux_skilled_gen_`x'08[1,2]
	matrix aux2_skilled_gen_`x'08=e(V)
	sca var=aux2_skilled_gen_`x'08[2,2]
	sca skilled_gen_sd_`x'08=sqrt(var)
dis skilled_gen_result_`x'08
dis skilled_gen_sd_`x'08
}
* Agrees with Final Report table 9.8 p. 122

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8<2): proportion skilled
	matrix aux_skilled_`x'08=e(b)
	sca skilled_result_`x'08=aux_skilled_`x'08[1,2]
	matrix aux2_skilled_`x'08=e(V)
	sca var=aux2_skilled_`x'08[2,2]
	sca skilled_sd_`x'08=sqrt(var)
dis skilled_result_`x'08
dis skilled_sd_`x'08
}
restore


*****************
*  HIV testing  *
*****************

* Females
preserve
use "KEIR51FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen hivtest=0 
replace hivtest=1 if v826==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion hivtest
	matrix aux_hiv_F_`x'08=e(b)
	sca hiv_F_result_`x'08=aux_hiv_F_`x'08[1,2]
	matrix aux2_hiv_F_`x'08=e(V)
	sca var=aux2_hiv_F_`x'08[2,2]
	sca hiv_F_sd_`x'08=sqrt(var)
dis hiv_F_result_`x'08
dis hiv_F_sd_`x'08
}
restore
* Agrees with Final Report table 13.9.1 p. 191

* Males
preserve
use "KEMR51FL.DTA", clear
gen all = 1
gen rural = mv025 == 2
gen mvregion = (mv024 == 5 & mv025 == 2)
gen weight = mv005/1e6
svyset mv001 [pweight=weight], strata(mv022) 
gen hivtest=0 
replace hivtest=1 if mv826==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & mv012<50): proportion hivtest 				//male up to 49 years
	matrix aux_hiv_M_`x'08=e(b)
	sca hiv_M_result_`x'08=aux_hiv_M_`x'08[1,2]
	matrix aux2_hiv_M_`x'08=e(V)
	sca var=aux2_hiv_M_`x'08[2,2]
	sca hiv_M_sd_`x'08=sqrt(var)
dis hiv_M_result_`x'08
dis hiv_M_sd_`x'08
}
restore
* Agrees with Final Report table 13.9.2 p. 192

* Weighted average of F and M indicator value
gen female=hv104==2		//dummy for female

foreach x of varlist all rural mvregion {
summ female [w=weight] if hv105<50 & hv105>14 & `x'		//population share of females (population aged 15-49)
	sca pop_share_F_`x'08 = r(mean)
	sca pop_share_M_`x'08 = 1 - pop_share_F_`x'08
sca hiv_result_`x'08 = pop_share_M_`x'08*hiv_M_result_`x'08 + pop_share_F_`x'08*hiv_F_result_`x'08
dis hiv_result_`x'08
sca hiv_sd_`x'08=sqrt((pop_share_F_`x'08 * hiv_F_sd_`x'08)^2 + ((1 - pop_share_F_`x'08) * hiv_M_sd_`x'08)^2)
}


**************
*  Stunting  *
**************
preserve
use "KEPR51FL.DTA", clear

* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 5 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture set, clear
svyset hv001 [pweight=weight], strata(hv022) 

*** Checking for comparison to Final Report
gen age_months = hc1
gen stunted=1 if (hc70<-200 & hv103==1) 
replace stunted=0 if (hc70>=-200 & hc70<601 & hv103==1)

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion stunted 
	matrix aux_stunted_gen_`x'08=e(b)
	sca stunted_gen_result_`x'08=aux_stunted_gen_`x'08[1,2]
	matrix aux2_stunted_gen_`x'08=e(V)
	sca var=aux2_stunted_gen_`x'08[2,2]
	sca stunted_gen_sd_`x'08=sqrt(var)
}
* Agrees with Final Report table 11.2 p. 145

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_months<24): proportion stunted 
	matrix aux_stunted_`x'08=e(b)
	sca stunted_result_`x'08=aux_stunted_`x'08[1,2]
	matrix aux2_stunted_`x'08=e(V)
	sca var=aux2_stunted_`x'08[2,2]
	sca stunted_sd_`x'08=sqrt(var)
dis stunted_result_`x'08
dis stunted_sd_`x'08
}
restore

**********************
* Malaria prevalence *
**********************

preserve
use "KEKR51FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen fever = h22
replace fever=0 if (h22==9 | h22==8)

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion fever 
	matrix aux_fever_`x'08=e(b)
	sca fever_result_`x'08=aux_fever_`x'08[1,2]
	matrix aux2_fever_`x'08=e(V)
	sca var=aux2_fever_`x'08[2,2]
	sca fever_sd_`x'08=sqrt(var)
dis fever_result_`x'08
dis fever_sd_`x'08
}
restore
* Agrees with Final Report table 12.5 p. 169


********************
********************
**                **
**   KENYA 2003   **
**                **
********************
********************

use "KEPR42FL.DTA", clear

* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 5 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Creating a subset of one observation per household.
sort hhid
by hhid: gen hhmem = 1 if _n == 1
replace hhmem = 0 if hhmem ==.


***************
*  Schooling  *
***************

*** Checking for comparison to Final Report
gen attended_primary = hv122==1 if (hv105>5 & hv103==1)
gen age = hv105
gen primaryage = (age >= 6 & age <= 13) if hv103==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): total attended_primary 
	matrix aux_prim_students_`x'03 = e(b)
	sca prim_students_`x'03=aux_prim_students_`x'03[1,1] 
svy, subpop (if `x'): total primaryage
	matrix aux_prim_age_kids_`x'03 = e(b)
	sca prim_age_kids_`x'03=aux_prim_age_kids_`x'03[1,1]
sca prim_result_gen_`x'03 = prim_students_`x'03/prim_age_kids_`x'03	
dis prim_result_gen_`x'03
svy, subpop (if `x'): ratio attended_primary / primaryage
}
* NOTE: Slightly different from Kenya DHS 2003 Final Report Table 2.5 page 20

*** Recalculating with numerator including children below 5 for comparability with MVP report
drop attended_primary
gen attended_primary = hv122==1 if hv103==1

/* Use bootstrap command to produce standard errors. Bootstrap does not allow pweights => transform the
variables first. Check against the classical way of calculating the GPA ratio */

gen prage=weight*primaryage if attended_primary!=.
gen attprimary=weight*attended_primary

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): ratio attended_primary / primaryage
*bootstrap, rep(1000) strata(hv022) cluster(hv001): ratio attprimary / prage if `x'
	matrix aux_gpa_`x'03=e(b)
	sca prim_result_`x'03=aux_gpa_`x'03[1,1]
	matrix aux2_gpa_`x'03=e(V)
	sca var=aux2_gpa_`x'03[1,1]
	sca prim_sd_`x'03=sqrt(var)
dis prim_result_`x'03
dis prim_sd_`x'03
}

*************
*  Bednets  *
*************

gen age_new=hml16
gen itn=hml12==1

foreach x of varlist all rural mvregion {
svy, subpop (if (age_new<5 & hv103==1 & `x')): proportion itn 
	matrix aux_itn_`x'03=e(b)
	sca itn_result_`x'03=aux_itn_`x'03[1,2]
	matrix aux2_itn_`x'03=e(V)
	sca var=aux2_itn_`x'03[2,2]
	sca itn_sd_`x'03=sqrt(var)
sca itn_result_`x'03=itn_result_`x'03
sca itn_sd_`x'03=itn_sd_`x'03
dis itn_result_`x'03
dis itn_sd_`x'03
}
* NOTE: Different from Kenya DHS 2003 Final Report Table 11.2 page 173


*******************
*  Mobile phones  *
*******************

* Note: mobile phone or landline
gen hasphone = hv221 == 1
replace hasphone = 0 if hv221 == 9
preserve
sort hhid
by hhid: egen anyphone = max(hasphone)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1 ): proportion anyphone 
	matrix aux_phone_`x'03=e(b)
	sca phone_result_`x'03=aux_phone_`x'03[1,2]
	matrix aux2_phone_`x'03=e(V)
	sca var=aux2_phone_`x'03[2,2]
	sca phone_sd_`x'03=sqrt(var)
dis phone_result_`x'03
dis phone_sd_`x'03
}
restore
* Agrees with Final Report table 2.7 p. 25


**********
*  Water *
**********

/* Final Report 2003 does not provide a statistic for improved water, so check calculation against 
reported value of percent of households with "Piped into dwelling/yard/plot" as source of drinking water. */

gen piped_water = (hv201 == 11| hv201 == 12)
by hhid: egen hhpiped_water = max(piped_water)

svy, subpop ( if hhmem == 1): proportion hhpiped_water
svy, subpop ( if rural==1 & hhmem == 1): proportion hhpiped_water

/* There is only 1 category for "spring" in 2003 whereas there are two categories in 2008:
protected spring (improved) and unprotected spring (not improved).
"Relative" and "absolute" percentage of protected spring was saved in 2008 and will be used for further analysis */

gen improved_water = 0
replace improved_water = 1 if (hv201 >= 10 & hv201 <= 13) | (hv201 >= 30 & hv201 <= 33) | hv201 == 51 
by hhid: egen hhimproved_water = max(improved_water)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1): proportion hhimproved_water  
	matrix aux_water_`x'03=e(b)
	sca water_result0_`x'03=aux_water_`x'03[1,2]
	matrix aux2_water_`x'03=e(V)
	sca var=aux2_water_`x'03[2,2]
	sca water_sd0_`x'03=sqrt(var)
dis water_result0_`x'03
dis water_sd0_`x'03
}

/* 1. Approach: We assume that the "relative" proportion of protected springs out of all springs 
(protected and unprotected) was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hv201
	matrix aux_water_`x'03=e(b)
	sca aux_water1_`x'03=aux_water_`x'03[1,8]		//percentage of springs in 2003
	dis aux_water1_`x'03
sca water_result1_`x'03 = water_result0_`x'03 + aux_water1_`x'03 * spring_relative_`x'08
	//result 2003 plus (% of springs in 2003 * proportion of protected springs out of all springs in 2008)
	sca water_sd1_`x'03=0
dis water_result1_`x'03
dis water_sd1_`x'03
}

/* 2. Approach: We assume that the "absolute" proportion of protected springs out of all types of water 
supply types was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
sca water_result2_`x'03 = water_result0_`x'03 + spring_absolute_`x'08	//result 2003 plus % of protected springs in 2008
	sca water_sd2_`x'03= sqrt(((water_sd0_`x'03)^2)+((spring_absolutesd_`x'08)^2))
dis water_result2_`x'03
dis water_sd2_`x'03
}


****************
*  Sanitation  *
****************

/* Final Report 2003 does not provide a statistic for improved sanitation, so check calculation against 
reported value of percent of households with "Flush toilet" as sanitation facility. */

gen flush_toilet = hv205 == 11
replace flush_toilet = . if hv205 == 99
by hhid: egen hhflush_toilet = max(flush_toilet)
svy, subpop ( if hhmem == 1): proportion hhflush_toilet
svy, subpop ( if rural==1 & hhmem == 1): proportion hhflush_toilet

/* The MV report does *not* define 'shared' as 'unimproved'.
There is only 1 category for "traditional pit latrine" in 2003 whereas there are two categories in 2008:
with slab (improved) and without slab (not improved).
"Relative" and "absolute" percentage of latrine with slab was saved in 2008 and will be used for further analysis */

gen improved_sanitation = 0
replace improved_sanitation = 1 if (hv205 == 11 | hv205== 22) 
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hhimproved_sanitation
	matrix aux_sani_`x'03=e(b)
	sca sani_result0_`x'03=aux_sani_`x'03[1,2]
	matrix aux2_sani_`x'03=e(V)
	sca var=aux2_sani_`x'03[2,2]
	sca sani_sd0_`x'03=sqrt(var)
dis sani_result0_`x'03
dis sani_sd0_`x'03
}

/* 1. Approach: We assume that the "relative" proportion of latrines with slab out of all latrines 
(with and without slab) was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hv205
	matrix aux_sani_`x'03=e(b)
	sca aux_sani1_`x'03=aux_sani_`x'03[1,2]		//percentage of pit latrines in 2003
	dis aux_sani1_`x'03
sca sani_result1_`x'03 = sani_result0_`x'03 + aux_sani1_`x'03 * slab_relative_`x'08
	//result 2003 plus (% of pit latrines in 2003 * proportion of latrines with slab out of pit latrines in 2008)
	sca sani_sd1_`x'03=0
dis sani_result1_`x'03
dis sani_sd1_`x'03
}

/* 2. Approach: We assume that the "absolute" proportion of latrines with slab out of all types of sanitation 
facilities was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
sca sani_result2_`x'03 = sani_result0_`x'03 + slab_absolute_`x'08	//result 2003 plus % of latrines with slab in 2008
	sca sani_sd2_`x'03=sqrt(((sani_sd0_`x'03)^2) + ((slab_absolutesd_`x'08)^2))
dis sani_result2_`x'03
dis sani_sd2_`x'03
}


*************************
*  Measles vaccination  *
*************************

preserve
use "KEKR41FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen age_years = b8
gen measles = (h9 == 1 | h9 == 2 | h9 == 3)
* Note: the survey asks mothers if children aged 12-23 months received vaccinations at any time before the survey:

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_years==1): proportion measles 
	matrix aux_measles_`x'03=e(b)
	sca measles_result_`x'03=aux_measles_`x'03[1,2]
	matrix aux2_measles_`x'03=e(V)
	sca var=aux2_measles_`x'03[2,2]
	sca measles_sd_`x'03=sqrt(var)
dis measles_result_`x'03
dis measles_sd_`x'03
}
restore
* Agrees with Kenya DHS 2003 Final Report Table 9.12 page 139


**********************
*  Birth attendance  *
**********************

preserve
use "KEKR41FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen skilled = .
replace skilled = 1 if m3a == 1 | m3b == 1
replace skilled = 0 if skilled != 1 & (m3a != . | m3b != . | m3c != . | m3d != .)
replace skilled=0 if skilled==.

*** Checking for comparison to Final Report
foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion skilled 
	matrix aux_skilled_gen_`x'03=e(b)
	sca skilled_gen_result_`x'03=aux_skilled_gen_`x'03[1,2]
	matrix aux2_skilled_gen_`x'03=e(V)
	sca var=aux2_skilled_gen_`x'03[2,2]
	sca skilled_gen_sd_`x'03=sqrt(var)
dis skilled_gen_result_`x'03
dis skilled_gen_sd_`x'03
}
* Agrees with Final Report table 9.7 p. 132

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8<2): proportion skilled 
	matrix aux_skilled_`x'03=e(b)
	sca skilled_result_`x'03=aux_skilled_`x'03[1,2]
	matrix aux2_skilled_`x'03=e(V)
	sca var=aux2_skilled_`x'03[2,2]
	sca skilled_sd_`x'03=sqrt(var)
dis skilled_result_`x'03
dis skilled_sd_`x'03
}
restore


*****************
*  HIV testing  *
*****************

* Females
preserve
use "KEIR41FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen hivtest=0 
replace hivtest=1 if v826==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion hivtest 
	matrix aux_hiv_F_`x'03=e(b)
	sca hiv_F_result_`x'03=aux_hiv_F_`x'03[1,2]
	matrix aux2_hiv_F_`x'03=e(V)
	sca var=aux2_hiv_F_`x'03[2,2]
	sca hiv_F_sd_`x'03=sqrt(var)
dis hiv_F_result_`x'03
dis hiv_F_sd_`x'03
}
restore
* Agrees with Final Report table 12.10 p. 198

* Males
preserve
use "KEMR41FL.DTA", clear
gen all = 1
gen rural = mv025 == 2
gen mvregion = (mv024 == 5 & mv025 == 2)
gen weight = mv005/1e6
svyset mv001 [pweight=weight], strata(mv022) 
gen hivtest=0 
replace hivtest=1 if mv826==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & mv012<50): proportion hivtest 				//male up to 49 years
	matrix aux_hiv_M_`x'03=e(b)
	sca hiv_M_result_`x'03=aux_hiv_M_`x'03[1,2]
	matrix aux2_hiv_M_`x'03=e(V)
	sca var=aux2_hiv_M_`x'03[2,2]
	sca hiv_M_sd_`x'03=sqrt(var)
dis hiv_M_result_`x'03
dis hiv_M_sd_`x'03
}
restore
* Agrees with Final Report table 12.10 p. 198

* Weighted average of F and M indicator value
gen female=hv104==2		//dummy for female

foreach x of varlist all rural mvregion {
summ female [w=weight] if hv105<50 & hv105>14 & `x'		//population share of females (population aged 15-49)
	sca pop_share_F_`x'03 = r(mean)
	sca pop_share_M_`x'03 = 1 - pop_share_F_`x'03
sca hiv_result_`x'03 = pop_share_M_`x'03*hiv_M_result_`x'03 + pop_share_F_`x'03*hiv_F_result_`x'03
dis hiv_result_`x'03
sca hiv_sd_`x'03=sqrt((pop_share_F_`x'03 * hiv_F_sd_`x'03)^2 + ((1 - pop_share_F_`x'03) * hiv_M_sd_`x'03 )^2)
}


**************
*  Stunting  *
**************
preserve
use "KEPR42FL.DTA", clear
sort hhid hvidx
keep  hhid hvidx hv001 hv005 hv022 hv024 hv025 hv103 hc1
rename hhid hwhhid
rename hvidx hwline
tempfile kenya_who
save "`kenya_who'", replace

use "KEHW41FL.DTA", clear
sort hwhhid hwline
merge 1:1 hwhhid hwline using "`kenya_who'"
save "`kenya_who'", replace

* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 5 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

gen age_months = hc1
gen stunted=1 if (hc70<-200 & hv103==1) 
replace stunted=0 if (hc70>=-200 & hc70<601 & hv103==1)

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_months<24): proportion stunted
matrix aux_stunted_`x'03=e(b)
	sca stunted_result_`x'03=aux_stunted_`x'03[1,2]
	matrix aux2_stunted_`x'03=e(V)
	sca var=aux2_stunted_`x'03[2,2]
	sca stunted_sd_`x'03=sqrt(var)
dis stunted_result_`x'03
dis stunted_sd_`x'03
}
restore
**********************
* Malaria prevalence *
**********************

preserve
use "KEKR41FL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 5 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
keep if b5==1
gen fever=0
replace fever = 1 if (ml12==1 | h22==1)

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion fever 
	matrix aux_fever_`x'03=e(b)
	sca fever_result_`x'03=aux_fever_`x'03[1,2]
	matrix aux2_fever_`x'03=e(V)
	sca var=aux2_fever_`x'03[2,2]
	sca fever_sd_`x'03=sqrt(var)
dis fever_result_`x'03
dis fever_sd_`x'03
}
restore
* Agrees with Final Report table 12.5 p. 179


*****************
*****************
**   RESULTS   **
*****************
*****************


*** Generating matrices
* 1. of final results

matrix R = (prim_result_all03, itn_result_all03, phone_result_all03, measles_result_all03, skilled_result_all03, stunted_result_all03, hiv_result_all03, fever_result_all03, sani_result1_all03, sani_result2_all03, water_result1_all03, water_result2_all03 \ prim_result_rural03, itn_result_rural03, phone_result_rural03, measles_result_rural03, skilled_result_rural03, stunted_result_rural03, hiv_result_rural03, fever_result_rural03, sani_result1_rural03, sani_result2_rural03, water_result1_rural03, water_result2_rural03\ prim_result_mvregion03, itn_result_mvregion03, phone_result_mvregion03, measles_result_mvregion03, skilled_result_mvregion03, stunted_result_mvregion03, hiv_result_mvregion03, fever_result_mvregion03, sani_result1_mvregion03, sani_result2_mvregion03, water_result1_mvregion03, water_result2_mvregion03\prim_result_all08, itn_result_all08, phone_result_all08, measles_result_all08, skilled_result_all08, stunted_result_all08, hiv_result_all08, fever_result_all08, sani_result2_all08, sani_result2_all08, water_result2_all08, water_result2_all08\ prim_result_rural08, itn_result_rural08, phone_result_rural08, measles_result_rural08, skilled_result_rural08, stunted_result_rural08, hiv_result_rural08, fever_result_rural08, sani_result2_rural08, sani_result2_rural08, water_result2_rural08, water_result2_rural08\ prim_result_mvregion08, itn_result_mvregion08, phone_result_mvregion08, measles_result_mvregion08, skilled_result_mvregion08, stunted_result_mvregion08, hiv_result_mvregion08, fever_result_mvregion08, sani_result2_mvregion08, sani_result2_mvregion08, water_result2_mvregion08, water_result2_mvregion08)
matrix colnames R = prim_result itn_result phone_result measles_result skilled_result stunted_result hiv_result fever_result sani_result1 sani_result2 water_result1 water_result2
matrix rownames R = All2003 Rural2003 Mvregion2003 All2008 Rural2008 Mvregion2008
matlist R

svmat R

* 2. of standard errors
matrix S = (prim_sd_all03, itn_sd_all03, phone_sd_all03, measles_sd_all03, skilled_sd_all03, stunted_sd_all03, hiv_sd_all03, fever_sd_all03, sani_sd1_all03, sani_sd2_all03, water_sd1_all03, water_sd2_all03\prim_sd_rural03, itn_sd_rural03, phone_sd_rural03, measles_sd_rural03, skilled_sd_rural03, stunted_sd_rural03, hiv_sd_rural03, fever_sd_rural03, sani_sd1_rural03, sani_sd2_rural03, water_sd1_rural03, water_sd2_rural03\prim_sd_mvregion03, itn_sd_mvregion03, phone_sd_mvregion03, measles_sd_mvregion03, skilled_sd_mvregion03, stunted_sd_mvregion03, hiv_sd_mvregion03, fever_sd_mvregion03, sani_sd1_mvregion03, sani_sd2_mvregion03, water_sd1_mvregion03, water_sd2_mvregion03\prim_sd_all08, itn_sd_all08, phone_sd_all08, measles_sd_all08, skilled_sd_all08, stunted_sd_all08, hiv_sd_all08, fever_sd_all08, sani_sd2_all08, sani_sd2_all08, water_sd2_all08, water_sd2_all08\prim_sd_rural08, itn_sd_rural08, phone_sd_rural08, measles_sd_rural08, skilled_sd_rural08, stunted_sd_rural08, hiv_sd_rural08, fever_sd_rural08, sani_sd2_rural08, sani_sd2_rural08, water_sd2_rural08, water_sd2_rural08\prim_sd_mvregion08, itn_sd_mvregion08, phone_sd_mvregion08, measles_sd_mvregion08, skilled_sd_mvregion08, stunted_sd_mvregion08, hiv_sd_mvregion08, fever_sd_mvregion08, sani_sd2_mvregion08, sani_sd2_mvregion08, water_sd2_mvregion08, water_sd2_mvregion08)
matrix colnames S = prim_sd itn_sd phone_sd measles_sd skilled_sd stunted_sd hiv_sd fever_sd sani_sd1 sani_sd2 water_sd1 water_sd2
matrix rownames S = All2003 Rural2003 Mvregion2003 All2008 Rural2008 Mvregion2008
matlist S

svmat S

* Generating dataset of final results
rename R1 prim_result
rename R2 itn_result
rename R3 phone_result
rename R4 measles_result
rename R5 skilled_result
rename R6 stunted_result
rename R7 hiv_result
rename R8 fever_result
rename R9 sani_result1
rename R10 sani_result2
rename R11 water_result1
rename R12 water_result2

rename S1 prim_sd
rename S2 itn_sd
rename S3 phone_sd
rename S4 measles_sd
rename S5 skilled_sd
rename S6 stunted_sd
rename S7 hiv_sd
rename S8 fever_sd
rename S9 sani_sd1
rename S10 sani_sd2
rename S11 water_sd1
rename S12 water_sd2

* Creating variables for year and coverage. 
input year coverage
2003 1
2003 2
2003 3
2008 1
2008 2
2008 3
end

tempfile kenya_output
save "`kenya_output'", replace

******************
******************
***   GRAPHS   ***
******************
******************
use "`kenya_output'", clear

clear
set obs 2
local vars "year coverage prim_result itn_result phone_result measles_result skilled_result hiv_result stunted_result fever_result"
foreach x of local vars {
	gen `x' = .
}
replace coverage = 4
replace year = 2005 if _n==1
replace year = 2008 if _n==2

* Add data on Millennium Village
* The following data taken from MVP report "Harvests of Development in Rural Africa: The Millennium Villages After Three Years", p. 87.

replace prim_result = 1.10 if year == 2005
replace itn_result = .10 if year == 2005
replace phone_result = .10 if year == 2005
replace measles_result = .67 if year == 2005
replace skilled_result = .51 if year == 2005
replace hiv_result = .14 if year == 2005
replace stunted_result = .62 if year == 2005
replace fever_result = .50 if year == 2005


replace prim_result = 1.23 if year == 2008
replace itn_result = .62 if year == 2008
replace phone_result = .40 if year == 2008
replace measles_result = .98 if year == 2008
replace skilled_result = .46 if year == 2008
replace hiv_result = .58 if year == 2008
replace stunted_result = .38 if year == 2008
replace fever_result = .08 if year == 2008


label define coveragetypes 1 "Country" 2 "Rural" 3 "MV region, rural" 4 "Millennium Village"
label values coverage coveragetypes

append using "`kenya_output'"
order coverage year
sort coverage year
save "`kenya_output'", replace

* Create graphs

graph twoway scatter sani_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter sani_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter sani_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter sani_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter sani_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter sani_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter water_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter water_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter water_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter water_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000
	
graph twoway scatter measles_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter measles_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter measles_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter measles_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Measles vaccination, age < 1", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter skilled_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter skilled_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Skilled attendant at birth, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter hiv_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter hiv_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: HIV testing in last year, age 15-49", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000
	
graph twoway scatter itn_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter itn_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter itn_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter itn_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: ITN usage, age < 5", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter stunted_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter stunted_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Stunting, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000

graph twoway scatter prim_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter prim_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter prim_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter prim_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Gross primary attendance ratio", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

sleep 10000
	
graph twoway scatter phone_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter phone_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter phone_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter phone_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Mobile phone ownership, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)
	
sleep 10000

/* Create graphs (version with legends)

use "`kenya_output'"
pause on 

graph twoway scatter sani_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter sani_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter sani_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(1 2 3) cols(2) lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

/*graph twoway scatter sani_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter sani_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter sani_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(1 2 3) cols(2) lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)*/

pause  

graph twoway scatter water_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter water_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(1 2 3) cols(2) lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

/*graph twoway scatter water_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter water_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(1 2 3) cols(2) lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)*/

pause  
	
graph twoway scatter measles_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter measles_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter measles_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter measles_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Measles vaccination, age < 1", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

graph twoway scatter skilled_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter skilled_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Skilled attendant at birth, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

graph twoway scatter hiv_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter hiv_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: HIV testing in last year, age 15-49", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  
	
graph twoway scatter itn_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter itn_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter itn_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter itn_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: ITN usage, age < 5", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

graph twoway scatter stunted_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter stunted_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Stunting, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  

graph twoway scatter prim_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter prim_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter prim_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter prim_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Kenya}: Gross primary attendance ratio", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause  
	
graph twoway scatter phone_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter phone_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter phone_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter phone_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Kenya}: Mobile phone ownership, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)
	
pause  
*/
******************
******************
***   TABLES   ***
******************
******************

clear

set obs 22
g aux = 1
g indicator = sum(aux)
drop aux

* Each observation stands for an indicator or its standard error

foreach k in all03 rural03 mvregion03 all08 rural08 mvregion08 { 
gen `k'=.
}

* Every even observation refers to the indicator, every uneven to its standard error

foreach k in all03 rural03 mvregion03 all08 rural08 mvregion08 { 
capture replace `k'=sani_result1_`k' if indicator==1
capture replace `k'=sani_result2_`k' if indicator==3
capture replace `k'=water_result1_`k' if indicator==5
capture replace `k'=water_result2_`k' if indicator==7
capture replace `k'=measles_result_`k' if indicator==9
capture replace `k'=skilled_result_`k' if indicator==11
capture replace `k'=hiv_result_`k' if indicator==13
capture replace `k'=itn_result_`k' if indicator==15
capture replace `k'=stunted_result_`k' if indicator==17
capture replace `k'=prim_result_`k' if indicator==19
capture replace `k'=phone_result_`k' if indicator==21
capture replace `k'=sani_sd1_`k' if indicator==2
capture replace `k'=sani_sd2_`k' if indicator==4
capture replace `k'=water_sd1_`k' if indicator==6
capture replace `k'=water_sd2_`k' if indicator==8
capture replace `k'=measles_sd_`k' if indicator==10
capture replace `k'=skilled_sd_`k' if indicator==12
capture replace `k'=hiv_sd_`k' if indicator==14
capture replace `k'=itn_sd_`k' if indicator==16
capture replace `k'=stunted_sd_`k' if indicator==18
capture replace `k'=prim_sd_`k' if indicator==20
capture replace `k'=phone_sd_`k' if indicator==22
}

order indicator all03 all08 rural03 rural08 mvregion03 mvregion08

browse

saveold "kenya_table.dta", replace

